//
// vrml.cpp  written by Kenji Shimada
// Problem Set 9 Sample Code 
//

#include  "regression.h"

extern double data[6][6];

void vrml_reg (ofstream &outFile, char* my_name, double a[]) {
// Draw in the output vrml file, axes, data points, and surface
//  outFile: pointer to the output vrml file
//  my_name: my name to be shown in the heading
//	a[]:     coefficients of qadratic surface
	
	int			i, j;
	double		x1, x2;

	// Create Header
	outFile << "#VRML V2.0 utf8\n";
	outFile << "#------------------------------------------------\n";
	outFile << "# 24-311: Numerical Methods  Fall'98\n";
	outFile << "# "<<MY_NAME<<"\n";
	outFile << "# Two Dimensional Quadratic Regression\n";
	outFile << "#------------------------------------------------\n\n";

	// Set up background
	outFile << "# Specify the background color\n";
	outFile << "#-----------------------------------\n";
	outFile << "Background {\n\tskyColor 1 1 1\n}\n\n"; // White background

	// Create the square for the canvas
//	outFile << "# Draw the first canvas\n";
//	outFile << "#-----------------------------------\n";
//	outFile << "Transform {\n";
//	outFile << "\trotation 1 0 0 1.5707\n";
//	outFile << "\ttranslation 10 0 10\n";
//	outFile << "\tchildren Shape {\n";
//	outFile << "\t\tappearance Appearance {\n";
//	outFile << "\t\t\tmaterial Material {\n";
//	outFile << "\t\t\t\tdiffuseColor 0.0 0.9 0.9\n";
//	outFile << "\t\t\t\ttransparency 0.5\n\t\t\t}\n\t\t}\n";
//	outFile << "\t\tgeometry Box {\n";
//	outFile << "\t\t\tsize 20 20 0.1\n\t\t}\n\t}\n}\n\n";

	// Put text heading on the VRML screen
	outFile << "# Draw texts\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 10 26 1\n";
	outFile << "\tchildren Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 1 0 0\n";
	outFile << "\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Text {\n";
	outFile << "\t\t\tstring [\"24-311: Numerical Methods--PS7\",\n";
	outFile << "\t\t\t\"2D Quadratic Regression\",\n";
	outFile << "\t\t\t\""<<MY_NAME<<"\"]\n";
	outFile << "\t\t\tfontStyle FontStyle {\n";
	outFile << "\t\t\t\tfamily \"SANS\"\n";
	outFile << "\t\t\t\tjustify \"MIDDLE\"\n";
	outFile << "\t\t\t\tstyle \"BOLD\"\n";
	outFile << "\t\t\t\tsize 1.5\n\t\t\t}\n\t\t}\n\t}\n}\n\n";

	// Add the x-axis
	outFile << "# Define the x axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 0 0 0\n";
	outFile << "\tchildren DEF AXIS Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 0.0 0.0 0.0\n\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Extrusion {\n";
	outFile << "\t\t\tcrossSection [1 0, 0 -1, -1 0, 0 1, 1 0]\n";
	outFile << "\t\t\tscale [0.1 0.1, 0.1 0.1, 0.4 0.4, 0 0]\n";
	outFile << "\t\t\tspine [0 0 0, 21 0 0, 21 0 0, 22 0 0]\n\t\t}\n\t}\n}\n\n";

	// Add the y-axis
	outFile << "# Draw the y axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\trotation 0 0 1 1.5707\n";
	outFile << "\tchildren USE AXIS\n}\n\n";

	// Add the z-axis
	outFile << "# Draw the z axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\trotation 0 1 0 -1.5707\n";
	outFile << "\tchildren USE AXIS\n}\n\n";

	// Draw data points
	outFile << "# Draw data points\n";
	outFile << "#-----------------------------------\n";
	for(i=0; i<6; i++)
		for(j=0; j<6; j++){
			outFile << "Transform {\n";
			outFile << "\ttranslation " << j*4.0 <<" "<< 20.0*data[i][j] <<" "<< i*4.0 <<"\n";
			outFile << "\tchildren Shape {\n";
			outFile << "\t\tappearance Appearance {\n";
			outFile << "\t\t\tmaterial Material {\n";
			outFile << "\t\t\t\tdiffuseColor 1.0 0.0 0.0\n";
			outFile << "\t\t\t}\n";
			outFile << "\t\t}\n";
			outFile << "\t\tgeometry Sphere {\n";
			outFile << "\t\t\tradius 0.5\n\t\t}\n\t}\n}\n\n";
		}

	// Draw the surface
	outFile << "# Draw the surface\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 0 0 0\n";
	outFile << "\tchildren Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 0.0 1.0 0.0\n";
	outFile << "\t\t\t\ttransparency 0.25\n";
	outFile << "\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry ElevationGrid{\n";
	outFile << "\t\t\tsolid FALSE\n";
	outFile << "\t\t\txDimension " << SURF_PREC <<"\n";
	outFile << "\t\t\tzDimension " << SURF_PREC <<"\n";
	outFile << "\t\t\txSpacing " << X_SPACING <<"\n";
	outFile << "\t\t\tzSpacing " << Y_SPACING <<"\n";
	outFile << "\t\t\theight [";
	for (i=0; i<SURF_PREC; i++)
		for (j=0; j<SURF_PREC; j++){
			x1=i/(double) SURF_PREC;
			x2=j/(double) SURF_PREC;
			outFile << 20.0*( a[0] + a[1]*x1 + a[2]*x2 
					     + a[3]*x1*x2 + a[4]*x1*x1 + a[5]*x2*x2) << ", ";
		}
		
	outFile << "]\n";

	outFile << "\n\t\t}\n\t}\n}\n\n";

}